local L = AceLibrary("AceLocale-2.2"):new("Fence_AutoFill")

-- Localization
L:RegisterTranslations("enUS", function() 
	return {
		["auction runtime"] = true,
		["Set default auction runtime."] = true,
		["Remember last used auction runtime."] = true,
		["Toggles auto-fill module."] = true,
		["auto fill"] = true,
		["%s now set to %s hours."] = true,
		["Type in 2, 8 or 24"] = true,
		["Last auction runtime"] = true,
		["Duration"] = true
	}
end)

L:RegisterTranslations("deDE", function() 
	return {
		["auction runtime"] = "Auktionslaufzeit",
		["Set default auction runtime."] = "Ändert Standard-Auktionslaufzeit.",
		["Remember last used auction runtime."] = "Merkt sich zuletzt benutzte Auktionslaufzeit.",
		["Toggles auto-fill module."] = "Schaltet Auto-Ausf\195\188llen Modul ein/aus.",
		["auto fill"] = "Automatisches Ausf\195\188llen",
		["%s now set to %s hours."] = "%s auf %s Stunden ge\195\164ndert.",
		["Type in 2, 8 or 24"] = "2, 8 oder 24 eingeben",
		["Last auction runtime"] = "Letzte Auktionslaufzeit",
		["Duration"] = "Dauer"
	}
end)

Fence_AutoFill = Fence:NewModule("AutoFill")

	function Fence_AutoFill:OnInitialize()
		self.db = Fence:AcquireDBNamespace("AutoFill")
		if not self.db.profile.prices then self.db.profile.prices = {} end
		if not self.db.profile.lastduration then self.db.profile.lastduration = 480 end
		
		Fence.options.args.autofill = {
			type = 'group',
			desc = "Auto Fill options",
				args = {
					toggle = {
						type = 'toggle',
						name = L["auto fill"],
						desc = L["Toggles auto-fill module."],
						get = function() return Fence:IsModuleActive("AutoFill") end,
						set = function(v) Fence:ToggleModuleActive("AutoFill", v) end
					},
					duration = {
						type = 'text',
						name = L["Duration"],
						desc = L["Set default auction runtime."],
						usage = L["Type in 2, 8 or 24"],
						message = L["%s now set to %s hours."],
						get	= function() return self.db.profile.dur end,
						set =	function(v) self.db.profile.dur = v end,
						validate = {"2", "8", "24"}
					},
					last = {
						type = 'toggle',
						name = L["auction runtime"],
						desc = L["Remember last used auction runtime."],
						get	= function() return self.db.profile.last end,
						set =	function(v) self.db.profile.last = v end
					}
				}
		}
	end
	
	function Fence_AutoFill:OnEnable()
		self:RegisterEvent("AH_LOADED")
		self:RegisterEvent("AUCTION_OWNED_LIST_UPDATE")
	end
	
	function Fence_AutoFill:AH_LOADED()
		self:Hook("StartAuction", true)
		self:Hook("AuctionSellItemButton_OnEvent", true)
		self:UnregisterEvent("AH_LOADED")
	end
	
	function Fence_AutoFill:AUCTION_OWNED_LIST_UPDATE()
		local d, sa, ma, la, du
		if self.db.profile.last then
			du = self.db.profile.lastduration
			if du == 120 then 
				sa, ma, la  = 1, 0, 0
			elseif du == 480 then
				sa, ma, la = 0, 1, 0
			elseif du == 1440 then
				sa, ma, la  = 0, 0, 1
			else
				return
			end
			self:SetDur(sa, ma, la, du) 
			return
		end
		if self.db.profile.dur then
			d = tonumber(self.db.profile.dur)
			if d == 2 then
				sa, ma, la, du  = 1, 0, 0, 120
			elseif d == 8 then
				sa, ma, la, du  = 0, 1, 0, 480
			elseif d == 24 then
				sa, ma, la, du  = 0, 0, 1, 1440
			else 
				return
			end
			self:SetDur(sa, ma, la, du) 
			return
		end
	end
	
	function Fence_AutoFill:SetDur(sa, ma, la, du)
		AuctionsShortAuctionButton:SetChecked(sa)
		AuctionsMediumAuctionButton:SetChecked(ma)
		AuctionsLongAuctionButton:SetChecked(la)
		AuctionFrameAuctions.duration = du
	end
	
	function Fence_AutoFill:AuctionSellItemButton_OnEvent()
		self.hooks["AuctionSellItemButton_OnEvent"]()
		local name, texture, count, quality, canUse, price = GetAuctionSellItemInfo()
		local db = self.db.profile.prices[name]
		if not db then return end
		MoneyInputFrame_SetCopper(StartPrice, db.s * count)
		MoneyInputFrame_SetCopper(BuyoutPrice, db.b * count)
	end
	
	function Fence_AutoFill:StartAuction(start, buyout, duration)
		local name, texture, count, quality, canUse, price = GetAuctionSellItemInfo()
		local db = self.db.profile.prices[name] or {}
		db.s = start  / count
		db.b = buyout / count
		self.db.profile.prices[name] = db
		if self.db.profile.last then self.db.profile.lastduration = duration end
		self.hooks["StartAuction"](start, buyout, duration)
	end