local L = AceLibrary("AceLocale-2.2"):new("Fence_BidWatch")
local abc = AceLibrary("Abacus-2.0")

-- Localization
L:RegisterTranslations("enUS", function() return {
		["Bid"] = true,
		["Set upper bid limit in copper (default: 10000)"] = true,
		["WARNING!!!\n\nBid is greater than:\n"] = true,
		["\n\nAre you sure you wish to bid?"] = true,
		["Bid for %s detected."] = true,
		["Toggles Bid Watch module."] = true,
	}
end)

L:RegisterTranslations("deDE", function() return {
		["Bid"] = "Gebot",
		["Set upper bid limit in copper (default: 10000)"] = 
			"Legt Limit f\195\188r Gebote in Kupfer fest (Standard: 10000)",
		["WARNING!!!\n\nBid is greater than:\n"] = "WARNUNG!!!\n\nGebot ist gr\195\182\195\159er als:\n",
		["\n\nAre you sure you wish to bid?"] = "\n\nM\195\182chtest du trotzdem bieten?",
		["Bid for %s detected."] = "Gebot in H\195\182he von %s entdeckt.",
		["Toggles Bid Watch module."] = "Schaltet Bid Watch Modul ein/aus.",

	}
end)

Fence_BidWatch = Fence:NewModule("BidWatch")
	
	function Fence_BidWatch:OnInitialize()
		self.db = Fence:AcquireDBNamespace("BidWatch")
		if not self.db.profile.MaxBid then self.db.profile.MaxBid = 10000 end
		
		Fence.options.args.bidwatch = {
			type = 'group',
			desc = "Bid Watch options",
				args = {
					toggle = {
						type = 'toggle',
						name = "Bid Watch",
						desc = L["Toggles Bid Watch module."],
						get = function() return Fence:IsModuleActive("AutoFill") end,
						set = function(v) Fence:ToggleModuleActive("AutoFill", v) end
					},
					bid = {
						name = L["Bid"], 
						desc = L["Set upper bid limit in copper (default: 10000)"],
						type = "range",
						get = function() return abc:FormatMoneyFull(self.db.profile.MaxBid, true) end,
						set = function(v)	
								self.db.profile.MaxBid = v 
								self:CreatePopup()
								end,
						min = 1,
						max = 5000000,
						step = 1
					}
				}
			}
		
	end

	function Fence_BidWatch:OnEnable()
		self:RegisterEvent("AH_LOADED")
		self:CreatePopup()
	end
	
	function Fence_BidWatch:AH_LOADED()
		self:Hook("PlaceAuctionBid", true)
		self:UnregisterEvent("AH_LOADED")
	end
	
	function Fence_BidWatch:CreatePopup()
		StaticPopupDialogs["BID_BIND"] = {
			text = TEXT(L["WARNING!!!\n\nBid is greater than:\n"]..abc:FormatMoneyFull(self.db.profile.MaxBid, true)..L["\n\nAre you sure you wish to bid?"]),
			button1 = TEXT(OKAY),
			button2 = TEXT(CANCEL),
			OnAccept = function()
				self.hooks["PlaceAuctionBid"](self.itemtype ,self.itemindex ,self.bidamount)
			end,
			showAlert = 1,
			timeout = 0,
			exclusive = 1,
			whileDead = 1,
			interruptCinematic = 1
		}	
	end
	
	function Fence_BidWatch:PlaceAuctionBid(itemtype,itemindex,bidamount)
		self.itemtype = itemtype
		self.itemindex = itemindex
		self.bidamount = bidamount
		
		if bidamount >= self.db.profile.MaxBid then
			local dialog = StaticPopup_Show("BID_BIND")
			if dialog then 
				self:Print(L["Bid for %s detected."], abc:FormatMoneyFull(bidamount,true)) 
			else 
				self.hooks["PlaceAuctionBid"](itemtype, itemindex ,bidamount)			
			end
		else
			self.hooks["PlaceAuctionBid"](itemtype, itemindex ,bidamount)
		end
	end